searchNodes=[{"ref":"BSV.html","title":"BSV","type":"module","doc":"Elixir Bitcoin SV library."},{"ref":"BSV.Crypto.AES.html","title":"BSV.Crypto.AES","type":"module","doc":"Functions for use with AES symmetric cryptography. Examples iex&gt; secret = BSV.Crypto.AES.generate_secret ...&gt; ...&gt; &quot;hello world&quot; ...&gt; |&gt; BSV.Crypto.AES.encrypt(:gcm, secret) ...&gt; |&gt; BSV.Crypto.AES.decrypt(:gcm, secret) &quot;hello world&quot;"},{"ref":"BSV.Crypto.AES.html#cipher_modes/0","title":"BSV.Crypto.AES.cipher_modes/0","type":"function","doc":"Returns a list of supported cypher modes."},{"ref":"BSV.Crypto.AES.html#decrypt/4","title":"BSV.Crypto.AES.decrypt/4","type":"function","doc":"Decrypts the given ciphertext using the specified cipher mode with the given secret key. Options The accepted cipher modes are: :gcm - Galois/Counter Mode (GCM) :cbc - Cipher Block Chaining (CBC) :ctr - Counter (CTR) The accepted options are: :aad - If Additional Authentication Data was specified at encryption, it must be used here to successfully decrypt. :iv - If your own initialization vector was specified at encryption, it must be used here to successfully decrypt. Examples iex&gt; &quot;Mku/VQR8uf3UIkCpX2vau+s3sGtGOhvbf+buZ6AC5L1obQlLPgEq&quot; ...&gt; |&gt; Base.decode64! ...&gt; |&gt; BSV.Crypto.AES.decrypt(:gcm, BSV.Test.symetric_key, iv: BSV.Test.iv12, aad: &quot;MyAAD&quot;) &quot;hello world&quot; iex&gt; &quot;quZoaDPv4OXNC5Ze2wmbCA==&quot; ...&gt; |&gt; Base.decode64! ...&gt; |&gt; BSV.Crypto.AES.decrypt(:cbc, BSV.Test.symetric_key, iv: BSV.Test.iv16) &quot;hello world&quot; iex&gt; &quot;cdf91fda732325cf96de03&quot; ...&gt; |&gt; Base.decode16!(case: :lower) ...&gt; |&gt; BSV.Crypto.AES.decrypt(:ctr, BSV.Test.symetric_key, iv: BSV.Test.iv16) &quot;hello world&quot;"},{"ref":"BSV.Crypto.AES.html#encrypt/4","title":"BSV.Crypto.AES.encrypt/4","type":"function","doc":"Encrypts the given data using the specified cipher mode with the given secret key. Options The accepted cipher modes are: :gcm - Galois/Counter Mode (GCM) :cbc - Cipher Block Chaining (CBC) :ctr - Counter (CTR) The accepted options are: :aad - Provide your own Additional Authentication Data (only used in :gcm mode). If not provided, defaults to &quot;BSV.Crypto.AES&quot;. :encode - Optionally encode the returned cipher text with either the :base64 or :hex encoding scheme. :iv - Provide your own initialization vector. In :cbc and :ctr mode this is necessary as the same vector is needed to decrypt. In :gcm mode it is unnecessary as a random vector is generated and encoded in the returned cipher text. Examples iex&gt; BSV.Crypto.AES.encrypt(&quot;hello world&quot;, :gcm, BSV.Test.symetric_key, iv: BSV.Test.iv12, aad: &quot;MyAAD&quot;) &lt;&lt;50, 75, 191, 85, 4, 124, 185, 253, 212, 34, 64, 169, 95, 107, 218, 187, 235, 55, 176, 107, 70, 58, 27, 219, 127, 230, 238, 103, 160, 2, 228, 189, 104, 109, 9, 75, 62, 1, 42&gt;&gt; iex&gt; BSV.Crypto.AES.encrypt(&quot;hello world&quot;, :gcm, BSV.Test.symetric_key, iv: BSV.Test.iv12, aad: &quot;MyAAD&quot;, encode: :base64) &quot;Mku/VQR8uf3UIkCpX2vau+s3sGtGOhvbf+buZ6AC5L1obQlLPgEq&quot; iex&gt; BSV.Crypto.AES.encrypt(&quot;hello world&quot;, :cbc, BSV.Test.symetric_key, iv: BSV.Test.iv16, encode: :base64) &quot;quZoaDPv4OXNC5Ze2wmbCA==&quot; iex&gt; BSV.Crypto.AES.encrypt(&quot;hello world&quot;, :ctr, BSV.Test.symetric_key, iv: BSV.Test.iv16, encode: :hex) &quot;cdf91fda732325cf96de03&quot;"},{"ref":"BSV.Crypto.AES.html#generate_secret/0","title":"BSV.Crypto.AES.generate_secret/0","type":"function","doc":"Generate a 256 bit random secret key. Examples iex&gt; BSV.Crypto.AES.generate_secret ...&gt; |&gt; byte_size 32"},{"ref":"BSV.Crypto.ECDSA.html","title":"BSV.Crypto.ECDSA","type":"module","doc":"Functions for use with ECDSA asymmetric cryptography. Examples iex&gt; private_key = BSV.Crypto.ECDSA.generate_key ...&gt; public_key = BSV.Crypto.ECDSA.PrivateKey.get_public_key(private_key) ...&gt; ...&gt; message = &quot;hello world&quot; ...&gt; signature = BSV.Crypto.ECDSA.sign(message, private_key) ...&gt; BSV.Crypto.ECDSA.verify(message, signature, public_key) true"},{"ref":"BSV.Crypto.ECDSA.html#generate_key/1","title":"BSV.Crypto.ECDSA.generate_key/1","type":"function","doc":"Generates a new ECDSA private key. Options The accepted options are: :named_curve - Specify the elliptic curve name. Defaults to :secp256k1. Examples iex&gt; private_key = BSV.Crypto.ECDSA.generate_key ...&gt; (%BSV.Crypto.ECDSA.PrivateKey{} = private_key) == private_key true"},{"ref":"BSV.Crypto.ECDSA.html#generate_key_pair/1","title":"BSV.Crypto.ECDSA.generate_key_pair/1","type":"function","doc":"Generates a new ECDSA public and private key pair, returned as a tuple containing two binaries. Options The accepted options are: :named_curve - Specify the elliptic curve name. Defaults to :secp256k1. :private_key - Whena private key binary is given, it will be returned with its public key. Examples iex&gt; BSV.Crypto.ECDSA.generate_key_pair ...&gt; |&gt; is_tuple true iex&gt; ecdsa_key = BSV.Crypto.ECDSA.PrivateKey.from_sequence(BSV.Test.ecdsa_key) ...&gt; ...&gt; public_key = BSV.Crypto.ECDSA.generate_key_pair(private_key: ecdsa_key.private_key) ...&gt; |&gt; elem(0) ...&gt; public_key == ecdsa_key.public_key true"},{"ref":"BSV.Crypto.ECDSA.html#pem_decode/1","title":"BSV.Crypto.ECDSA.pem_decode/1","type":"function","doc":"Decodes the given PEM string into a ECDSA key. Examples iex&gt; ecdsa_key = BSV.Crypto.ECDSA.PrivateKey.from_sequence(BSV.Test.ecdsa_key) ...&gt; pem = BSV.Crypto.ECDSA.pem_encode(ecdsa_key) ...&gt; ...&gt; imported_key = BSV.Crypto.ECDSA.pem_decode(pem) ...&gt; imported_key == ecdsa_key true"},{"ref":"BSV.Crypto.ECDSA.html#pem_encode/1","title":"BSV.Crypto.ECDSA.pem_encode/1","type":"function","doc":"Encodes the given public or private key into a PEM string. Examples iex&gt; BSV.Crypto.ECDSA.PrivateKey.from_sequence(BSV.Test.ecdsa_key) ...&gt; |&gt; BSV.Crypto.ECDSA.pem_encode ...&gt; |&gt; String.starts_with?(&quot;-----BEGIN EC PRIVATE KEY-----&quot;) true"},{"ref":"BSV.Crypto.ECDSA.html#sign/3","title":"BSV.Crypto.ECDSA.sign/3","type":"function","doc":"Creates a signature for the given message, using the given private key. Options The accepted options are: :named_curve - Specific the elliptic curve name. Defaults to :secp256k1. :encode - Optionally encode the returned binary with either the :base64 or :hex encoding scheme. Examples BSV.Crypto.ECDSA.sign(&quot;hello world&quot;, private_key, encode: :base64) &lt;&lt; signature &gt;&gt;"},{"ref":"BSV.Crypto.ECDSA.html#verify/4","title":"BSV.Crypto.ECDSA.verify/4","type":"function","doc":"Verify the given message and signature, using the given private key. Options The accepted options are: :named_curve - Specific the elliptic curve name. Defaults to :secp256k1. Examples BSV.Crypto.RSA.verify(signature, public_key)"},{"ref":"BSV.Crypto.ECDSA.PrivateKey.html","title":"BSV.Crypto.ECDSA.PrivateKey","type":"module","doc":"ECDSA Private Key module."},{"ref":"BSV.Crypto.ECDSA.PrivateKey.html#as_sequence/1","title":"BSV.Crypto.ECDSA.PrivateKey.as_sequence/1","type":"function","doc":"Converts the given ECDSA private key to an Erlang ECDSA key sequence. Convert a BSV.Crypto.ECDSA.PrivateKey.t/0 to a BSV.Crypto.ECDSA.PrivateKey.sequence/0. Examples iex&gt; ecdsa_key = BSV.Crypto.ECDSA.PrivateKey.from_sequence(BSV.Test.ecdsa_key) ...&gt; ...&gt; BSV.Crypto.ECDSA.PrivateKey.as_sequence(ecdsa_key) ...&gt; |&gt; is_tuple true"},{"ref":"BSV.Crypto.ECDSA.PrivateKey.html#from_sequence/1","title":"BSV.Crypto.ECDSA.PrivateKey.from_sequence/1","type":"function","doc":"Converts the given Erlang ECDSA key sequence to a ECDSA private key. Examples iex&gt; ecdsa_key = BSV.Crypto.ECDSA.PrivateKey.from_sequence(BSV.Test.ecdsa_key) ...&gt; (%BSV.Crypto.ECDSA.PrivateKey{} = ecdsa_key) == ecdsa_key true"},{"ref":"BSV.Crypto.ECDSA.PrivateKey.html#get_public_key/1","title":"BSV.Crypto.ECDSA.PrivateKey.get_public_key/1","type":"function","doc":"Returns the public key from the given ECDSA private key. Examples iex&gt; public_key = BSV.Crypto.ECDSA.PrivateKey.from_sequence(BSV.Test.ecdsa_key) ...&gt; |&gt; BSV.Crypto.ECDSA.PrivateKey.get_public_key ...&gt; (%BSV.Crypto.ECDSA.PublicKey{} = public_key) == public_key true"},{"ref":"BSV.Crypto.ECDSA.PrivateKey.html#t:sequence/0","title":"BSV.Crypto.ECDSA.PrivateKey.sequence/0","type":"type","doc":"Erlang ECDSA Private Key sequence"},{"ref":"BSV.Crypto.ECDSA.PrivateKey.html#t:t/0","title":"BSV.Crypto.ECDSA.PrivateKey.t/0","type":"type","doc":"ECDSA Private Key"},{"ref":"BSV.Crypto.ECDSA.PublicKey.html","title":"BSV.Crypto.ECDSA.PublicKey","type":"module","doc":"ECDSA Private Key module."},{"ref":"BSV.Crypto.ECDSA.PublicKey.html#as_sequence/1","title":"BSV.Crypto.ECDSA.PublicKey.as_sequence/1","type":"function","doc":"Converts the given ECDSA public key struct to an Erlang EC point sequence. Examples iex&gt; public_key = BSV.Crypto.ECDSA.PrivateKey.from_sequence(BSV.Test.ecdsa_key) ...&gt; |&gt; BSV.Crypto.ECDSA.PrivateKey.get_public_key ...&gt; ...&gt; BSV.Crypto.ECDSA.PublicKey.as_sequence(public_key) ...&gt; |&gt; is_tuple true"},{"ref":"BSV.Crypto.ECDSA.PublicKey.html#t:point/0","title":"BSV.Crypto.ECDSA.PublicKey.point/0","type":"type","doc":"Erlang ECDSA Public Key sequence"},{"ref":"BSV.Crypto.ECDSA.PublicKey.html#t:t/0","title":"BSV.Crypto.ECDSA.PublicKey.t/0","type":"type","doc":"ECDSA Public Key"},{"ref":"BSV.Crypto.Hash.html","title":"BSV.Crypto.Hash","type":"module","doc":"A collection of one-way hashing functions."},{"ref":"BSV.Crypto.Hash.html#hash/3","title":"BSV.Crypto.Hash.hash/3","type":"function","doc":"Computes a hash of the given data, using the specified hash algorithm. Options The accepted hash algorithms are: :md5 - MD5 message-digest algorithm (128 bit) :ripemd160 - RIPE Message Digest algorithm (160 bit) :sha - Secure Hash Algorithm 1 (SHA-1) (160 bit) :sha224 - Secure Hash Algorithm 2 (SHA-2) (224 bit) :sha256 - Secure Hash Algorithm 2 (SHA-2) (256 bit) :sha384 - Secure Hash Algorithm 2 (SHA-2) (384 bit) :sha512 - Secure Hash Algorithm 2 (SHA-2) (512 bit) The accepted options are: :encode - Optionally encode the returned hash with either the :base64 or :hex encoding scheme. Examples iex&gt; BSV.Crypto.Hash.hash(&quot;hello world&quot;, :sha256) &lt;&lt;185, 77, 39, 185, 147, 77, 62, 8, 165, 46, 82, 215, 218, 125, 171, 250, 196, 132, 239, 227, 122, 83, 128, 238, 144, 136, 247, 172, 226, 239, 205, 233&gt;&gt; iex&gt; BSV.Crypto.Hash.hash(&quot;hello world&quot;, :sha256, encode: :hex) &quot;b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9&quot; iex&gt; BSV.Crypto.Hash.hash(&quot;hello world&quot;, :sha256, encode: :base64) &quot;uU0nuZNNPgilLlLX2n2r+sSE7+N6U4DukIj3rOLvzek=&quot;"},{"ref":"BSV.Crypto.Hash.html#hash_algorithms/0","title":"BSV.Crypto.Hash.hash_algorithms/0","type":"function","doc":"Returns a list of supported hash algorithms."},{"ref":"BSV.Crypto.Hash.html#ripemd160/2","title":"BSV.Crypto.Hash.ripemd160/2","type":"function","doc":"Computes the RIPEMD hash of a given input, outputting 160 bits. See BSV.Crypto.Hash.hash/3 for the accepted options. Examples iex&gt; BSV.Crypto.Hash.ripemd160(&quot;hello world&quot;) &lt;&lt;152, 198, 21, 120, 76, 203, 95, 229, 147, 111, 188, 12, 190, 157, 253, 180, 8, 217, 47, 15&gt;&gt; iex&gt; BSV.Crypto.Hash.ripemd160(&quot;hello world&quot;, encode: :hex) &quot;98c615784ccb5fe5936fbc0cbe9dfdb408d92f0f&quot;"},{"ref":"BSV.Crypto.Hash.html#sha1/2","title":"BSV.Crypto.Hash.sha1/2","type":"function","doc":"Computes the SHA-1 hash of a given input, outputting 160 bits. See BSV.Crypto.Hash.hash/3 for the accepted options. Examples iex&gt; BSV.Crypto.Hash.sha1(&quot;hello world&quot;) &lt;&lt;42, 174, 108, 53, 201, 79, 207, 180, 21, 219, 233, 95, 64, 139, 156, 233, 30, 232, 70, 237&gt;&gt; iex&gt; BSV.Crypto.Hash.sha1(&quot;hello world&quot;, encode: :hex) &quot;2aae6c35c94fcfb415dbe95f408b9ce91ee846ed&quot;"},{"ref":"BSV.Crypto.Hash.html#sha256/2","title":"BSV.Crypto.Hash.sha256/2","type":"function","doc":"Computes the SHA-2 hash of a given input, outputting 256 bits. See BSV.Crypto.Hash.hash/3 for the accepted options. Examples iex&gt; BSV.Crypto.Hash.sha256(&quot;hello world&quot;) &lt;&lt;185, 77, 39, 185, 147, 77, 62, 8, 165, 46, 82, 215, 218, 125, 171, 250, 196, 132, 239, 227, 122, 83, 128, 238, 144, 136, 247, 172, 226, 239, 205, 233&gt;&gt; iex&gt; BSV.Crypto.Hash.sha256(&quot;hello world&quot;, encode: :hex) &quot;b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9&quot;"},{"ref":"BSV.Crypto.Hash.html#sha256_ripemd160/2","title":"BSV.Crypto.Hash.sha256_ripemd160/2","type":"function","doc":"Computes a RIPEMD0160 hash of a SHA256 hash, outputting 160 bits. This is commonly used inside Bitcoin, particularly for Bitcoin addresses. See BSV.Crypto.Hash.hash/3 for the accepted options. Examples iex&gt; BSV.Crypto.Hash.sha256_ripemd160(&quot;hello world&quot;) &lt;&lt;215, 213, 238, 120, 36, 255, 147, 249, 76, 48, 85, 175, 147, 130, 200, 108, 104, 181, 202, 146&gt;&gt; iex&gt; BSV.Crypto.Hash.sha256_ripemd160(&quot;hello world&quot;, encode: :hex) &quot;d7d5ee7824ff93f94c3055af9382c86c68b5ca92&quot;"},{"ref":"BSV.Crypto.Hash.html#sha256_sha256/2","title":"BSV.Crypto.Hash.sha256_sha256/2","type":"function","doc":"Computes a double SHA256 hash. This hash function is commonly used inside Bitcoin, particularly for the hash of a block and the hash of a transaction. See BSV.Crypto.Hash.hash/3 for the accepted options. Examples iex&gt; BSV.Crypto.Hash.sha256_sha256(&quot;hello world&quot;) &lt;&lt;188, 98, 212, 184, 13, 158, 54, 218, 41, 193, 108, 93, 77, 159, 17, 115, 31, 54, 5, 44, 114, 64, 26, 118, 194, 60, 15, 181, 169, 183, 68, 35&gt;&gt; iex&gt; BSV.Crypto.Hash.sha256_sha256(&quot;hello world&quot;, encode: :hex) &quot;bc62d4b80d9e36da29c16c5d4d9f11731f36052c72401a76c23c0fb5a9b74423&quot;"},{"ref":"BSV.Crypto.Hash.html#sha512/2","title":"BSV.Crypto.Hash.sha512/2","type":"function","doc":"Computes the SHA-2 hash of a given input, outputting 512 bits. See BSV.Crypto.Hash.hash/3 for the accepted options. Examples iex&gt; BSV.Crypto.Hash.sha512(&quot;hello world&quot;, encode: :hex) &quot;309ecc489c12d6eb4cc40f50c902f2b4d0ed77ee511a7c7a9bcd3ca86d4cd86f989dd35bc5ff499670da34255b45b0cfd830e81f605dcf7dc5542e93ae9cd76f&quot; iex&gt; BSV.Crypto.Hash.sha512(&quot;hello world&quot;, encode: :base64) &quot;MJ7MSJwS1utMxA9QyQLytNDtd+5RGnx6m808qG1M2G+YndNbxf9JlnDaNCVbRbDP2DDoH2Bdz33FVC6TrpzXbw==&quot;"},{"ref":"BSV.Crypto.RSA.html","title":"BSV.Crypto.RSA","type":"module","doc":"Functions for use with RSA asymmetric cryptography. Examples iex&gt; private_key = BSV.Crypto.RSA.generate_key ...&gt; public_key = BSV.Crypto.RSA.PrivateKey.get_public_key(private_key) ...&gt; ...&gt; &quot;hello world&quot; ...&gt; |&gt; BSV.Crypto.RSA.encrypt(public_key) ...&gt; |&gt; BSV.Crypto.RSA.decrypt(private_key) &quot;hello world&quot; iex&gt; private_key = BSV.Crypto.RSA.generate_key ...&gt; public_key = BSV.Crypto.RSA.PrivateKey.get_public_key(private_key) ...&gt; ...&gt; message = &quot;hello world&quot; ...&gt; signature = BSV.Crypto.RSA.sign(message, private_key) ...&gt; BSV.Crypto.RSA.verify(message, signature, public_key) true"},{"ref":"BSV.Crypto.RSA.html#decrypt/3","title":"BSV.Crypto.RSA.decrypt/3","type":"function","doc":"Decrypts the encrypted data with the given public or private key. Examples BSV.Crypto.RSA.decrypt(encrypted_binary, public_or_private_key) &lt;&lt; decrypted binary &gt;&gt;"},{"ref":"BSV.Crypto.RSA.html#encrypt/3","title":"BSV.Crypto.RSA.encrypt/3","type":"function","doc":"Encrypts the given data with the given public or private key. The method implicitly assumes the use of a public key, but encryption is possible with a private key by passing the key in a tuple format: {:private, private_key}. Options The accepted options are: :encode - Optionally encode the returned binary with either the :base64 or :hex encoding scheme. :encode - Optionally encode the returned binary with either the :base64 or :hex encoding scheme. Examples BSV.Crypto.RSA.encrypt(&quot;hello world&quot;, public_or_private_key) &lt;&lt; encrypted binary &gt;&gt;"},{"ref":"BSV.Crypto.RSA.html#generate_key/1","title":"BSV.Crypto.RSA.generate_key/1","type":"function","doc":"Generates a new RSA private key. Options The accepted options are: :size - Specific the size of the RSA key. Defaults to 2048. Examples iex&gt; private_key = BSV.Crypto.RSA.generate_key ...&gt; (%BSV.Crypto.RSA.PrivateKey{} = private_key) == private_key true"},{"ref":"BSV.Crypto.RSA.html#pem_decode/1","title":"BSV.Crypto.RSA.pem_decode/1","type":"function","doc":"Decodes the given PEM string into a public or private key. Examples iex&gt; public_key = BSV.Crypto.RSA.PrivateKey.from_sequence(BSV.Test.rsa_key) ...&gt; |&gt; BSV.Crypto.RSA.PrivateKey.get_public_key ...&gt; pem = BSV.Crypto.RSA.pem_encode(public_key) ...&gt; ...&gt; imported_key = BSV.Crypto.RSA.pem_decode(pem) ...&gt; imported_key == public_key true"},{"ref":"BSV.Crypto.RSA.html#pem_encode/1","title":"BSV.Crypto.RSA.pem_encode/1","type":"function","doc":"Encodes the given public or private key into a PEM string. Examples iex&gt; BSV.Crypto.RSA.PrivateKey.from_sequence(BSV.Test.rsa_key) ...&gt; |&gt; BSV.Crypto.RSA.PrivateKey.get_public_key ...&gt; |&gt; BSV.Crypto.RSA.pem_encode ...&gt; |&gt; String.starts_with?(&quot;-----BEGIN RSA PUBLIC KEY-----&quot;) true iex&gt; BSV.Crypto.RSA.PrivateKey.from_sequence(BSV.Test.rsa_key) ...&gt; |&gt; BSV.Crypto.RSA.pem_encode ...&gt; |&gt; String.starts_with?(&quot;-----BEGIN RSA PRIVATE KEY-----&quot;) true"},{"ref":"BSV.Crypto.RSA.html#sign/3","title":"BSV.Crypto.RSA.sign/3","type":"function","doc":"Creates a signature for the given message, using the given private key. Options The accepted options are: :encode - Optionally encode the returned binary with either the :base64 or :hex encoding scheme. :salt_length - Specify the RSA-PSS salt length (defaults to 20). Examples BSV.Crypto.RSA.sign(&quot;hello world&quot;, private_key, encode: :base64) &lt;&lt; signature &gt;&gt;"},{"ref":"BSV.Crypto.RSA.html#verify/4","title":"BSV.Crypto.RSA.verify/4","type":"function","doc":"Verifies the given message and signature, using the given private key. Options The accepted options are: :salt_length - Specify the RSA-PSS salt length (defaults to 20). Examples BSV.Crypto.RSA.verify(signature, public_key)"},{"ref":"BSV.Crypto.RSA.PrivateKey.html","title":"BSV.Crypto.RSA.PrivateKey","type":"module","doc":"RSA Private Key module."},{"ref":"BSV.Crypto.RSA.PrivateKey.html#as_sequence/1","title":"BSV.Crypto.RSA.PrivateKey.as_sequence/1","type":"function","doc":"Converts the given RSA private key struct to an Erlang private key sequence. Examples iex&gt; private_key = BSV.Crypto.RSA.PrivateKey.from_sequence(BSV.Test.rsa_key) ...&gt; ...&gt; BSV.Crypto.RSA.PrivateKey.as_sequence(private_key) ...&gt; |&gt; is_tuple true"},{"ref":"BSV.Crypto.RSA.PrivateKey.html#from_sequence/1","title":"BSV.Crypto.RSA.PrivateKey.from_sequence/1","type":"function","doc":"Converts the given Erlang private key sequence to a RSA private key struct. Examples iex&gt; private_key = BSV.Crypto.RSA.PrivateKey.from_sequence(BSV.Test.rsa_key) ...&gt; (%BSV.Crypto.RSA.PrivateKey{} = private_key) == private_key true"},{"ref":"BSV.Crypto.RSA.PrivateKey.html#get_public_key/1","title":"BSV.Crypto.RSA.PrivateKey.get_public_key/1","type":"function","doc":"Returns the public key from the given RSA private key. Examples iex&gt; public_key = BSV.Crypto.RSA.PrivateKey.from_sequence(BSV.Test.rsa_key) ...&gt; |&gt; BSV.Crypto.RSA.PrivateKey.get_public_key ...&gt; (%BSV.Crypto.RSA.PublicKey{} = public_key) == public_key true"},{"ref":"BSV.Crypto.RSA.PrivateKey.html#t:sequence/0","title":"BSV.Crypto.RSA.PrivateKey.sequence/0","type":"type","doc":"Erlang RSA Private Key sequence"},{"ref":"BSV.Crypto.RSA.PrivateKey.html#t:t/0","title":"BSV.Crypto.RSA.PrivateKey.t/0","type":"type","doc":"RSA Private Key"},{"ref":"BSV.Crypto.RSA.PublicKey.html","title":"BSV.Crypto.RSA.PublicKey","type":"module","doc":"RSA Public Key module."},{"ref":"BSV.Crypto.RSA.PublicKey.html#as_sequence/1","title":"BSV.Crypto.RSA.PublicKey.as_sequence/1","type":"function","doc":"Converts the given RSA public key struct to an Erlang public key sequence.= Examples iex&gt; public_key = BSV.Crypto.RSA.PrivateKey.from_sequence(BSV.Test.rsa_key) ...&gt; |&gt; BSV.Crypto.RSA.PrivateKey.get_public_key ...&gt; ...&gt; BSV.Crypto.RSA.PublicKey.as_sequence(public_key) ...&gt; |&gt; is_tuple true"},{"ref":"BSV.Crypto.RSA.PublicKey.html#from_sequence/1","title":"BSV.Crypto.RSA.PublicKey.from_sequence/1","type":"function","doc":"Converts the given Erlang public key sequence to a RSA public key struct. Examples iex&gt; public_key_sequence = BSV.Crypto.RSA.PrivateKey.from_sequence(BSV.Test.rsa_key) ...&gt; |&gt; BSV.Crypto.RSA.PrivateKey.get_public_key ...&gt; |&gt; BSV.Crypto.RSA.PublicKey.as_sequence ...&gt; ...&gt; public_key = BSV.Crypto.RSA.PublicKey.from_sequence(public_key_sequence) ...&gt; (%BSV.Crypto.RSA.PublicKey{} = public_key) == public_key true"},{"ref":"BSV.Crypto.RSA.PublicKey.html#t:sequence/0","title":"BSV.Crypto.RSA.PublicKey.sequence/0","type":"type","doc":"Erlang RSA Public Key sequence"},{"ref":"BSV.Crypto.RSA.PublicKey.html#t:t/0","title":"BSV.Crypto.RSA.PublicKey.t/0","type":"type","doc":"RSA Public Key"},{"ref":"BSV.KeyPair.html","title":"BSV.KeyPair","type":"module","doc":"Module for generating and using Bitcoin key pairs."},{"ref":"BSV.KeyPair.html#from_ecdsa_key/2","title":"BSV.KeyPair.from_ecdsa_key/2","type":"function","doc":"Converts ECDSA keys to a BSV key pair. Options The accepted options are: :compressed - Specify whether to compress the given public key. Defaults to true. Examples iex&gt; keypair =BSV.KeyPair.from_ecdsa_key(BSV.Test.bsv_keys) ...&gt; (%BSV.KeyPair{} = keypair) == keypair true"},{"ref":"BSV.KeyPair.html#generate/1","title":"BSV.KeyPair.generate/1","type":"function","doc":"Generates a new BSV key pair. Options The accepted options are: :compressed - Specify whether to compress the generated public key. Defaults to true. Examples iex&gt; keypair = BSV.KeyPair.generate ...&gt; (%BSV.KeyPair{} = keypair) == keypair true"},{"ref":"BSV.KeyPair.html#get_address/1","title":"BSV.KeyPair.get_address/1","type":"function","doc":"Returns the Bitcoin address from the given key pair or public key. Examples iex&gt; BSV.Crypto.ECDSA.PrivateKey.from_sequence(BSV.Test.ecdsa_key) ...&gt; |&gt; BSV.KeyPair.from_ecdsa_key ...&gt; |&gt; BSV.KeyPair.get_address &quot;18cqNbEBxkAttxcZLuH9LWhZJPd1BNu1A5&quot; iex&gt; BSV.Crypto.ECDSA.PrivateKey.from_sequence(BSV.Test.ecdsa_key) ...&gt; |&gt; BSV.KeyPair.from_ecdsa_key(compressed: false) ...&gt; |&gt; BSV.KeyPair.get_address &quot;1N5Cu7YUPQhcwZaQLDT5KnDpRVKzFDJxsf&quot;"},{"ref":"BSV.KeyPair.html#wif_decode/1","title":"BSV.KeyPair.wif_decode/1","type":"function","doc":"Decodes the given Wallet Import Format (WIF) binary into a BSV key pair. Examples iex&gt; BSV.KeyPair.wif_decode(&quot;KyGHAK8MNohVPdeGPYXveiAbTfLARVrQuJVtd3qMqN41UEnTWDkF&quot;) ...&gt; |&gt; BSV.KeyPair.get_address &quot;18cqNbEBxkAttxcZLuH9LWhZJPd1BNu1A5&quot; iex&gt; BSV.KeyPair.wif_decode(&quot;5JH9eTJyj6bYopGhBztsDd4XvAbFNQkpZEw8AXYoQePtK1r86nu&quot;) ...&gt; |&gt; BSV.KeyPair.get_address &quot;1N5Cu7YUPQhcwZaQLDT5KnDpRVKzFDJxsf&quot;"},{"ref":"BSV.KeyPair.html#wif_encode/1","title":"BSV.KeyPair.wif_encode/1","type":"function","doc":"Encodes the given BSV key pair into a Wallet Import Format (WIF) binary. Examples iex&gt; BSV.Crypto.ECDSA.PrivateKey.from_sequence(BSV.Test.ecdsa_key) ...&gt; |&gt; BSV.KeyPair.from_ecdsa_key ...&gt; |&gt; BSV.KeyPair.wif_encode &quot;KyGHAK8MNohVPdeGPYXveiAbTfLARVrQuJVtd3qMqN41UEnTWDkF&quot; iex&gt; BSV.Crypto.ECDSA.PrivateKey.from_sequence(BSV.Test.ecdsa_key) ...&gt; |&gt; BSV.KeyPair.from_ecdsa_key(compressed: false) ...&gt; |&gt; BSV.KeyPair.wif_encode &quot;5JH9eTJyj6bYopGhBztsDd4XvAbFNQkpZEw8AXYoQePtK1r86nu&quot;"},{"ref":"BSV.KeyPair.html#t:t/0","title":"BSV.KeyPair.t/0","type":"type","doc":"BSV Key Pair"},{"ref":"BSV.Test.html","title":"BSV.Test","type":"module","doc":"A variety of helper functions to make the tests consistent in their usage of keys, etc. Please don&#39;t use these keys for anything other than testing."},{"ref":"BSV.Test.html#bsv_keys/0","title":"BSV.Test.bsv_keys/0","type":"function","doc":"Returns a generic BSV key pair."},{"ref":"BSV.Test.html#ecdsa_key/0","title":"BSV.Test.ecdsa_key/0","type":"function","doc":"Returns a generic ECDSA key (erlang sequence)."},{"ref":"BSV.Test.html#iv12/0","title":"BSV.Test.iv12/0","type":"function","doc":"Returns a 12 byte (96 bit) initialization vector."},{"ref":"BSV.Test.html#iv16/0","title":"BSV.Test.iv16/0","type":"function","doc":"Returns a 16 byte (128 bit) initialization vector."},{"ref":"BSV.Test.html#rsa_key/0","title":"BSV.Test.rsa_key/0","type":"function","doc":"Returns a generic RSA key (erlang sequence)."},{"ref":"BSV.Test.html#symetric_key/0","title":"BSV.Test.symetric_key/0","type":"function","doc":"Returns a generic symetric key."},{"ref":"BSV.Util.html","title":"BSV.Util","type":"module","doc":"A collection of commonly used helper methods."},{"ref":"BSV.Util.html#encode/2","title":"BSV.Util.encode/2","type":"function","doc":"Encodes the given binary data with the specified encoding scheme. Options The accepted encoding schemes are: :base64 - Encodes the binary using Base64 :hex - Encodes the binary using Base16 (hexidecimal), using lower character case Examples iex&gt; BSV.Util.encode(&quot;hello world&quot;, :base64) &quot;aGVsbG8gd29ybGQ=&quot; iex&gt; BSV.Util.encode(&quot;hello world&quot;, :hex) &quot;68656c6c6f20776f726c64&quot;"},{"ref":"BSV.Util.html#random_bytes/1","title":"BSV.Util.random_bytes/1","type":"function","doc":"Generates random bits for the given number of bytes. Examples iex&gt; iv = BSV.Util.random_bytes(16) ...&gt; bit_size(iv) 128"},{"ref":"readme.html","title":"BSV-ex","type":"extras","doc":"BSV-ex 🚨 This repo is a work in progress. Not production ready yet. Elixir Bitcoin SV library. The aim is to create a full-featured library that broadly covers the following: [x] General crypto functions (hash, ecdsa, rsa) [ ] Bitcoin specific crypto (Electrum compatible message encrypt/decrypt and sign/verify) [x] Bitcoin key pair generation and related functions [ ] HD seed and key derivation [ ] Transaction parsing, building and encoding Documentation can be found at https://hexdocs.pm/bsv."},{"ref":"readme.html#installation","title":"BSV-ex - Installation","type":"extras","doc":"The package can be installed by adding bsv to your list of dependencies in mix.exs: def deps do [ {:bsv, &quot;~&gt; 0.1.0-dev.1&quot;} ] end"},{"ref":"readme.html#license","title":"BSV-ex - License","type":"extras","doc":"© Copyright 2019 libitx. BSV-ex is free software and released under the MIT license."}]